.. _supported-options:

=================
Supported options
=================

Here are the options supported by each Monte Carlo program.

Beam
====

.. supported-options:: beam

Sample
======

.. supported-options:: sample

Analysis
========

.. supported-options:: analysis